% P41EstParm.m Parameters for estimator
%
% COPYRIGHT:  Aprend Technology and Robert E. ALvarez, 2013. All rights reserved.
 
%% init vars
post_title = 'P41EstParm';
% modify this for your computer
dirname = ['L:\Projects\Blog\Posts\' post_title '\'];
addpath([dirname 'code']);
MakeBlogPostFileLists(post_title);

%% calibrator data 
   % step wedge thicknesses, gm/cm^2
nsteps = 5;
A_calib_region = [5 30];   % boundaries of calibration region
zts = zmeshgrid([0,A_calib_region(1),nsteps],[0,A_calib_region(2),nsteps]);
zts = zts(:);
cdat.As = zcomp(zts);
   % the spectrum and attenuation coefficients
tube_voltage = 80; % keV  
[specnum,xray_energies,specdat] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum','clipzeros');
specdat.mus = [xraymu('Al',xray_energies) xraymu('C5O2H8',xray_energies)]; % aluminum and acrylic plastic
    % compute thresholds to equalize transmitted number of photons for each bin
    % attenuate with median thicknesses in calibration phantom: 2.5 cm Al and 15 cm plastic
nbins = 4;
Ninit = 10^7;
specdat.specnum = Ninit*specdat.specnum_norm.*exp(-specdat.mus*(A_calib_region/2)');
specdat.idx_threshold = OptimNbinsThresholds(specdat,nbins);
    % reload specdat.specnum with 0 thickness value
specdat.specnum = specdat.specnum_norm;
   % assume noise free calibration data. 
   % use the expected value of transmitted number of photons
cdat.ns = PHAbinCounts(cdat.As,specdat,specdat.idx_threshold);
   % divide by 0 thickness value ---the table has 0,0 as the first row
cdat.logI = -log(bsxfun(@rdivide,cdat.ns,cdat.ns(1,:)));  

%% compute the parameters and then the linear MLE
    % covariance from calibrator data in middle of calibration region
[mindist,idx]  = min(abs(zts - complex(A_calib_region(1),A_calib_region(2))/2));
RL = diag(1./cdat.ns(idx,:));  
M = (cdat.As\cdat.logI)'; % note transpose
RLi = inv(RL);
csMLE = inv(M'*RLi*M)*M'*RLi;

%%  plot of linear MLE error
fh = figure;
As_initfit = cdat.logI*(csMLE');
dAs = cdat.As - As_initfit;
arrows(As_initfit(:,1),As_initfit(:,2),dAs(:,1),dAs(:,2),'FaceColor','r','Cartesian');
hold on 
plot(As_initfit(:,1),As_initfit(:,2),'ok','markersize',14)
plot(cdat.As(:,1),cdat.As(:,2),'+k','markersize',14)
hold off
axis([-2 10 -5 35])
xlabel('A_1 (cm)','fontsize',11)
ylabel('A_2 (cm)','fontsize',11)
set(gca,'linewidth',1.4,'fontsize',11)  
figpsn = [200 200   675   500];
set(fh,'color','w','position',figpsn);

%% export the figure as png and eps
figno = sprintf('-f%d',fh);
fname = 'QuiverPlot';
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',6,'LockAxes',0,'color','cmyk');
    % export as png
set(fh,'papertype','usletter')
print(figno,'-dpng','-cmyk','-r100',[dirname fname '.png']) % resolution 100 dpi

