function ns4bins = PHAbinCounts(As,specdat,idx_threshold) 
% function ns4bins = PHAbinCounts.(As,specdat,idx_threshold) 
% PHA counts for each bin for each value of As
% inputs:
%  As:  an nthickness by nbasis column matrix 
%  specdat: a spectrum data struct for incident spectrum with fields
%        egy: x-ray energies
%        specnum: the photon number spectrum
%        mus: the basis materials attenuation coefficients at egy energies. 
%   idx_threshold: indices into the spectrum array for inter-bin energies
% outputs:
%   ns4bins: the total photon counts for each bin along columns for A values along rows
%   noise_dat: a struct with intermediate data
% REA 4/20/10 - 8/Sep/2013 10:04
% see also PoissonLambda. This is a simplified and faster version

nreqargs = 3;
assert(nargin >= nreqargs);
if nargin ==2
    idx_threshold = [];
end

[nthick,nbasis] = size(As);
nbins = numel(idx_threshold)+1;       

bin_edges = [0; idx_threshold(:);numel(specdat.egys)];
bin_idxs = cell(nbins,1);
for k = 1:nbins
    bin_idxs{k}= (bin_edges(k)+1):bin_edges(k+1);
end

transmission = exp(-As*specdat.mus'); % size = (nthick,nenergy)

   % photon counts for each thickness (nthick rows) for each energy (nenergy cols)
ns_spectrum = bsxfun(@times,transmission,specdat.specnum(:)'); 

ns4bins = zeros(nthick,nbins);
for kbin = 1:nbins
    ns4bins(:,kbin) = sum(ns_spectrum(:,bin_idxs{kbin}),2);
end
   